# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qoob/ui/preferences.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(600, 500)
        self.gridLayout_8 = QtWidgets.QGridLayout(Dialog)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.sideMenuList = QtWidgets.QListWidget(Dialog)
        self.sideMenuList.setMinimumSize(QtCore.QSize(150, 0))
        self.sideMenuList.setMaximumSize(QtCore.QSize(150, 16777215))
        self.sideMenuList.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.sideMenuList.setObjectName("sideMenuList")
        item = QtWidgets.QListWidgetItem()
        self.sideMenuList.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.sideMenuList.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.sideMenuList.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.sideMenuList.addItem(item)
        self.gridLayout.addWidget(self.sideMenuList, 0, 0, 1, 2)
        self.resetButton = QtWidgets.QPushButton(Dialog)
        self.resetButton.setObjectName("resetButton")
        self.gridLayout.addWidget(self.resetButton, 1, 0, 1, 2)
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Apply|QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 1, 2, 1, 1)
        self.stackedWidget = QtWidgets.QStackedWidget(Dialog)
        self.stackedWidget.setObjectName("stackedWidget")
        self.page_3 = QtWidgets.QWidget()
        self.page_3.setObjectName("page_3")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.page_3)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.groupBox_4 = QtWidgets.QGroupBox(self.page_3)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.dbAddButton = QtWidgets.QPushButton(self.groupBox_4)
        self.dbAddButton.setObjectName("dbAddButton")
        self.gridLayout_3.addWidget(self.dbAddButton, 2, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem, 2, 2, 1, 1)
        self.dbDeleteButton = QtWidgets.QPushButton(self.groupBox_4)
        self.dbDeleteButton.setObjectName("dbDeleteButton")
        self.gridLayout_3.addWidget(self.dbDeleteButton, 2, 1, 1, 1)
        self.dbResetButton = QtWidgets.QToolButton(self.groupBox_4)
        self.dbResetButton.setMinimumSize(QtCore.QSize(30, 0))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("icons/refresh.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.dbResetButton.setIcon(icon)
        self.dbResetButton.setObjectName("dbResetButton")
        self.gridLayout_3.addWidget(self.dbResetButton, 2, 3, 1, 1)
        self.dbTree = QtWidgets.QTreeWidget(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dbTree.sizePolicy().hasHeightForWidth())
        self.dbTree.setSizePolicy(sizePolicy)
        self.dbTree.setAlternatingRowColors(True)
        self.dbTree.setRootIsDecorated(False)
        self.dbTree.setObjectName("dbTree")
        self.dbTree.header().setDefaultSectionSize(220)
        self.dbTree.header().setStretchLastSection(True)
        self.gridLayout_3.addWidget(self.dbTree, 1, 0, 1, 4)
        self.gridLayout_2.addWidget(self.groupBox_4, 2, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.page_3)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.deleteConfirmBox = QtWidgets.QCheckBox(self.groupBox_3)
        self.deleteConfirmBox.setObjectName("deleteConfirmBox")
        self.gridLayout_7.addWidget(self.deleteConfirmBox, 1, 0, 1, 3)
        self.resumePlaybackBox = QtWidgets.QCheckBox(self.groupBox_3)
        self.resumePlaybackBox.setObjectName("resumePlaybackBox")
        self.gridLayout_7.addWidget(self.resumePlaybackBox, 0, 0, 1, 3)
        self.cleanFolderBox = QtWidgets.QCheckBox(self.groupBox_3)
        self.cleanFolderBox.setObjectName("cleanFolderBox")
        self.gridLayout_7.addWidget(self.cleanFolderBox, 2, 0, 1, 3)
        self.label_3 = QtWidgets.QLabel(self.groupBox_3)
        self.label_3.setObjectName("label_3")
        self.gridLayout_7.addWidget(self.label_3, 5, 0, 1, 1)
        self.fileManagerLine = QtWidgets.QLineEdit(self.groupBox_3)
        self.fileManagerLine.setObjectName("fileManagerLine")
        self.gridLayout_7.addWidget(self.fileManagerLine, 5, 1, 1, 2)
        self.gridLayout_2.addWidget(self.groupBox_3, 0, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_2.addItem(spacerItem1, 1, 0, 1, 1)
        self.stackedWidget.addWidget(self.page_3)
        self.page_4 = QtWidgets.QWidget()
        self.page_4.setObjectName("page_4")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.page_4)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.groupBox_2 = QtWidgets.QGroupBox(self.page_4)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.trayIconBox = QtWidgets.QCheckBox(self.groupBox_2)
        self.trayIconBox.setObjectName("trayIconBox")
        self.gridLayout_5.addWidget(self.trayIconBox, 0, 0, 1, 1)
        self.trayMinimizeBox = QtWidgets.QCheckBox(self.groupBox_2)
        self.trayMinimizeBox.setObjectName("trayMinimizeBox")
        self.gridLayout_5.addWidget(self.trayMinimizeBox, 0, 1, 1, 1)
        self.gridLayout_9.addWidget(self.groupBox_2, 2, 0, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_9.addItem(spacerItem2, 3, 0, 1, 1)
        self.groupBox_10 = QtWidgets.QGroupBox(self.page_4)
        self.groupBox_10.setObjectName("groupBox_10")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.groupBox_10)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.lightThemeRadio = QtWidgets.QRadioButton(self.groupBox_10)
        self.lightThemeRadio.setObjectName("lightThemeRadio")
        self.gridLayout_12.addWidget(self.lightThemeRadio, 0, 0, 1, 1)
        self.darkThemeRadio = QtWidgets.QRadioButton(self.groupBox_10)
        self.darkThemeRadio.setObjectName("darkThemeRadio")
        self.gridLayout_12.addWidget(self.darkThemeRadio, 0, 1, 1, 1)
        self.gridLayout_9.addWidget(self.groupBox_10, 0, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_9.addItem(spacerItem3, 1, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_9.addItem(spacerItem4, 5, 0, 1, 1)
        self.groupBox_7 = QtWidgets.QGroupBox(self.page_4)
        self.groupBox_7.setObjectName("groupBox_7")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.groupBox_7)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.artTriggerSelectionBox = QtWidgets.QCheckBox(self.groupBox_7)
        self.artTriggerSelectionBox.setObjectName("artTriggerSelectionBox")
        self.gridLayout_10.addWidget(self.artTriggerSelectionBox, 4, 0, 1, 1)
        self.line_2 = QtWidgets.QFrame(self.groupBox_7)
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridLayout_10.addWidget(self.line_2, 2, 1, 3, 1)
        spacerItem5 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_10.addItem(spacerItem5, 1, 0, 1, 1)
        self.artSizeBox = QtWidgets.QSpinBox(self.groupBox_7)
        self.artSizeBox.setMaximum(270)
        self.artSizeBox.setSingleStep(10)
        self.artSizeBox.setObjectName("artSizeBox")
        self.gridLayout_10.addWidget(self.artSizeBox, 3, 2, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_10.addItem(spacerItem6, 3, 3, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_7)
        self.label_5.setObjectName("label_5")
        self.gridLayout_10.addWidget(self.label_5, 2, 2, 1, 2)
        self.label = QtWidgets.QLabel(self.groupBox_7)
        self.label.setObjectName("label")
        self.gridLayout_10.addWidget(self.label, 2, 0, 1, 1)
        self.artTriggerMediaBox = QtWidgets.QCheckBox(self.groupBox_7)
        self.artTriggerMediaBox.setObjectName("artTriggerMediaBox")
        self.gridLayout_10.addWidget(self.artTriggerMediaBox, 3, 0, 1, 1)
        self.artShowEmptyBox = QtWidgets.QCheckBox(self.groupBox_7)
        self.artShowEmptyBox.setObjectName("artShowEmptyBox")
        self.gridLayout_10.addWidget(self.artShowEmptyBox, 0, 0, 1, 4)
        self.gridLayout_9.addWidget(self.groupBox_7, 4, 0, 1, 1)
        self.stackedWidget.addWidget(self.page_4)
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.gridLayout_18 = QtWidgets.QGridLayout(self.page)
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.groupBox_6 = QtWidgets.QGroupBox(self.page)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_6.sizePolicy().hasHeightForWidth())
        self.groupBox_6.setSizePolicy(sizePolicy)
        self.groupBox_6.setMaximumSize(QtCore.QSize(16777215, 200))
        self.groupBox_6.setObjectName("groupBox_6")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_6)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.sortSelectedList = QtWidgets.QListWidget(self.groupBox_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sortSelectedList.sizePolicy().hasHeightForWidth())
        self.sortSelectedList.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(7)
        self.sortSelectedList.setFont(font)
        self.sortSelectedList.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self.sortSelectedList.setObjectName("sortSelectedList")
        self.gridLayout_6.addWidget(self.sortSelectedList, 1, 0, 3, 1)
        spacerItem7 = QtWidgets.QSpacerItem(21, 89, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_6.addItem(spacerItem7, 3, 1, 1, 1)
        self.sortRemoveButton = QtWidgets.QToolButton(self.groupBox_6)
        self.sortRemoveButton.setArrowType(QtCore.Qt.RightArrow)
        self.sortRemoveButton.setObjectName("sortRemoveButton")
        self.gridLayout_6.addWidget(self.sortRemoveButton, 1, 1, 1, 1)
        self.sortAddButton = QtWidgets.QToolButton(self.groupBox_6)
        self.sortAddButton.setArrowType(QtCore.Qt.LeftArrow)
        self.sortAddButton.setObjectName("sortAddButton")
        self.gridLayout_6.addWidget(self.sortAddButton, 2, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.groupBox_6)
        self.label_10.setObjectName("label_10")
        self.gridLayout_6.addWidget(self.label_10, 0, 2, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_6)
        self.label_4.setObjectName("label_4")
        self.gridLayout_6.addWidget(self.label_4, 0, 0, 1, 1)
        self.sortAvailableList = QtWidgets.QListWidget(self.groupBox_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sortAvailableList.sizePolicy().hasHeightForWidth())
        self.sortAvailableList.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(7)
        self.sortAvailableList.setFont(font)
        self.sortAvailableList.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self.sortAvailableList.setObjectName("sortAvailableList")
        self.gridLayout_6.addWidget(self.sortAvailableList, 1, 2, 3, 1)
        self.sortByDefaultBox = QtWidgets.QCheckBox(self.groupBox_6)
        self.sortByDefaultBox.setObjectName("sortByDefaultBox")
        self.gridLayout_6.addWidget(self.sortByDefaultBox, 4, 0, 1, 1)
        self.gridLayout_18.addWidget(self.groupBox_6, 2, 0, 1, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.page)
        self.groupBox_5.setObjectName("groupBox_5")
        self.gridLayout_14 = QtWidgets.QGridLayout(self.groupBox_5)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.stripTitlesBox = QtWidgets.QCheckBox(self.groupBox_5)
        self.stripTitlesBox.setObjectName("stripTitlesBox")
        self.gridLayout_14.addWidget(self.stripTitlesBox, 1, 0, 1, 2)
        self.label_12 = QtWidgets.QLabel(self.groupBox_5)
        self.label_12.setObjectName("label_12")
        self.gridLayout_14.addWidget(self.label_12, 3, 0, 1, 1)
        self.titleFormatLine = QtWidgets.QLineEdit(self.groupBox_5)
        self.titleFormatLine.setObjectName("titleFormatLine")
        self.gridLayout_14.addWidget(self.titleFormatLine, 3, 1, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.groupBox_5)
        self.label_11.setObjectName("label_11")
        self.gridLayout_14.addWidget(self.label_11, 4, 0, 1, 1)
        self.notificationFormatLine = QtWidgets.QLineEdit(self.groupBox_5)
        self.notificationFormatLine.setObjectName("notificationFormatLine")
        self.gridLayout_14.addWidget(self.notificationFormatLine, 4, 1, 1, 1)
        self.expandLibraryBox = QtWidgets.QCheckBox(self.groupBox_5)
        self.expandLibraryBox.setObjectName("expandLibraryBox")
        self.gridLayout_14.addWidget(self.expandLibraryBox, 0, 0, 1, 2)
        self.label_2 = QtWidgets.QLabel(self.groupBox_5)
        self.label_2.setObjectName("label_2")
        self.gridLayout_14.addWidget(self.label_2, 2, 0, 1, 1)
        self.tooltipFormatLine = QtWidgets.QLineEdit(self.groupBox_5)
        self.tooltipFormatLine.setObjectName("tooltipFormatLine")
        self.gridLayout_14.addWidget(self.tooltipFormatLine, 2, 1, 1, 1)
        self.gridLayout_18.addWidget(self.groupBox_5, 0, 0, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_18.addItem(spacerItem8, 3, 0, 1, 1)
        spacerItem9 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_18.addItem(spacerItem9, 1, 0, 1, 1)
        self.stackedWidget.addWidget(self.page)
        self.page_5 = QtWidgets.QWidget()
        self.page_5.setObjectName("page_5")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.page_5)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.groupBox = QtWidgets.QGroupBox(self.page_5)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_13 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_13.setObjectName("gridLayout_13")
        self.label_20 = QtWidgets.QLabel(self.groupBox)
        self.label_20.setMinimumSize(QtCore.QSize(50, 0))
        self.label_20.setObjectName("label_20")
        self.gridLayout_13.addWidget(self.label_20, 0, 3, 1, 1)
        self.popupFontFamilyCombo = QtWidgets.QFontComboBox(self.groupBox)
        self.popupFontFamilyCombo.setMaximumSize(QtCore.QSize(160, 16777215))
        self.popupFontFamilyCombo.setObjectName("popupFontFamilyCombo")
        self.gridLayout_13.addWidget(self.popupFontFamilyCombo, 0, 4, 1, 1)
        spacerItem10 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_13.addItem(spacerItem10, 0, 2, 1, 1)
        self.label_19 = QtWidgets.QLabel(self.groupBox)
        self.label_19.setMinimumSize(QtCore.QSize(40, 0))
        self.label_19.setObjectName("label_19")
        self.gridLayout_13.addWidget(self.label_19, 0, 0, 1, 1)
        self.popupFontSizeBox = QtWidgets.QSpinBox(self.groupBox)
        self.popupFontSizeBox.setObjectName("popupFontSizeBox")
        self.gridLayout_13.addWidget(self.popupFontSizeBox, 0, 1, 1, 1)
        self.gridLayout_11.addWidget(self.groupBox, 2, 0, 1, 2)
        self.groupBox_9 = QtWidgets.QGroupBox(self.page_5)
        self.groupBox_9.setObjectName("groupBox_9")
        self.gridLayout_15 = QtWidgets.QGridLayout(self.groupBox_9)
        self.gridLayout_15.setObjectName("gridLayout_15")
        self.popupVOffsetBox = QtWidgets.QSpinBox(self.groupBox_9)
        self.popupVOffsetBox.setMinimum(-9999)
        self.popupVOffsetBox.setMaximum(9999)
        self.popupVOffsetBox.setObjectName("popupVOffsetBox")
        self.gridLayout_15.addWidget(self.popupVOffsetBox, 1, 4, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.groupBox_9)
        self.label_7.setObjectName("label_7")
        self.gridLayout_15.addWidget(self.label_7, 1, 2, 1, 1)
        self.label_24 = QtWidgets.QLabel(self.groupBox_9)
        self.label_24.setAlignment(QtCore.Qt.AlignCenter)
        self.label_24.setObjectName("label_24")
        self.gridLayout_15.addWidget(self.label_24, 3, 0, 1, 1)
        self.popupHeightBox = QtWidgets.QSpinBox(self.groupBox_9)
        self.popupHeightBox.setMaximum(400)
        self.popupHeightBox.setSingleStep(5)
        self.popupHeightBox.setObjectName("popupHeightBox")
        self.gridLayout_15.addWidget(self.popupHeightBox, 3, 4, 1, 1)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_15.addItem(spacerItem11, 0, 3, 1, 1)
        self.popupHOffsetBox = QtWidgets.QSpinBox(self.groupBox_9)
        self.popupHOffsetBox.setMinimum(-9999)
        self.popupHOffsetBox.setMaximum(9999)
        self.popupHOffsetBox.setObjectName("popupHOffsetBox")
        self.gridLayout_15.addWidget(self.popupHOffsetBox, 0, 4, 1, 1)
        self.popupWidthBox = QtWidgets.QSpinBox(self.groupBox_9)
        self.popupWidthBox.setMaximum(400)
        self.popupWidthBox.setSingleStep(5)
        self.popupWidthBox.setObjectName("popupWidthBox")
        self.gridLayout_15.addWidget(self.popupWidthBox, 2, 4, 1, 1)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_15.addItem(spacerItem12, 0, 1, 1, 1)
        self.label_22 = QtWidgets.QLabel(self.groupBox_9)
        self.label_22.setObjectName("label_22")
        self.gridLayout_15.addWidget(self.label_22, 2, 2, 1, 1)
        self.label_25 = QtWidgets.QLabel(self.groupBox_9)
        self.label_25.setObjectName("label_25")
        self.gridLayout_15.addWidget(self.label_25, 3, 2, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_9)
        self.label_6.setObjectName("label_6")
        self.gridLayout_15.addWidget(self.label_6, 0, 2, 1, 1)
        self.frame = QtWidgets.QFrame(self.groupBox_9)
        self.frame.setMaximumSize(QtCore.QSize(75, 75))
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_16 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_16.setObjectName("gridLayout_16")
        self.middleRightRadio = QtWidgets.QRadioButton(self.frame)
        self.middleRightRadio.setText("")
        self.middleRightRadio.setObjectName("middleRightRadio")
        self.gridLayout_16.addWidget(self.middleRightRadio, 1, 2, 1, 1)
        self.bottomRightRadio = QtWidgets.QRadioButton(self.frame)
        self.bottomRightRadio.setText("")
        self.bottomRightRadio.setObjectName("bottomRightRadio")
        self.gridLayout_16.addWidget(self.bottomRightRadio, 2, 2, 1, 1)
        self.middleCenterRadio = QtWidgets.QRadioButton(self.frame)
        self.middleCenterRadio.setText("")
        self.middleCenterRadio.setObjectName("middleCenterRadio")
        self.gridLayout_16.addWidget(self.middleCenterRadio, 1, 1, 1, 1)
        self.topLeftRadio = QtWidgets.QRadioButton(self.frame)
        self.topLeftRadio.setText("")
        self.topLeftRadio.setObjectName("topLeftRadio")
        self.gridLayout_16.addWidget(self.topLeftRadio, 0, 0, 1, 1)
        self.bottomCenterRadio = QtWidgets.QRadioButton(self.frame)
        self.bottomCenterRadio.setText("")
        self.bottomCenterRadio.setObjectName("bottomCenterRadio")
        self.gridLayout_16.addWidget(self.bottomCenterRadio, 2, 1, 1, 1)
        self.bottomLeftRadio = QtWidgets.QRadioButton(self.frame)
        self.bottomLeftRadio.setText("")
        self.bottomLeftRadio.setObjectName("bottomLeftRadio")
        self.gridLayout_16.addWidget(self.bottomLeftRadio, 2, 0, 1, 1)
        self.middleLeftRadio = QtWidgets.QRadioButton(self.frame)
        self.middleLeftRadio.setText("")
        self.middleLeftRadio.setObjectName("middleLeftRadio")
        self.gridLayout_16.addWidget(self.middleLeftRadio, 1, 0, 1, 1)
        self.topRightRadio = QtWidgets.QRadioButton(self.frame)
        self.topRightRadio.setText("")
        self.topRightRadio.setObjectName("topRightRadio")
        self.gridLayout_16.addWidget(self.topRightRadio, 0, 2, 1, 1)
        self.topCenterRadio = QtWidgets.QRadioButton(self.frame)
        self.topCenterRadio.setText("")
        self.topCenterRadio.setObjectName("topCenterRadio")
        self.gridLayout_16.addWidget(self.topCenterRadio, 0, 1, 1, 1)
        self.gridLayout_15.addWidget(self.frame, 0, 0, 3, 1)
        self.gridLayout_11.addWidget(self.groupBox_9, 4, 0, 1, 2)
        spacerItem13 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_11.addItem(spacerItem13, 1, 0, 1, 2)
        self.groupBox_8 = QtWidgets.QGroupBox(self.page_5)
        self.groupBox_8.setObjectName("groupBox_8")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBox_8)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.label_21 = QtWidgets.QLabel(self.groupBox_8)
        self.label_21.setObjectName("label_21")
        self.gridLayout_4.addWidget(self.label_21, 2, 0, 1, 1)
        self.popupBackgroundButton = QtWidgets.QToolButton(self.groupBox_8)
        self.popupBackgroundButton.setObjectName("popupBackgroundButton")
        self.gridLayout_4.addWidget(self.popupBackgroundButton, 1, 4, 1, 1)
        self.popupForegroundButton = QtWidgets.QToolButton(self.groupBox_8)
        self.popupForegroundButton.setObjectName("popupForegroundButton")
        self.gridLayout_4.addWidget(self.popupForegroundButton, 2, 4, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.groupBox_8)
        self.label_13.setObjectName("label_13")
        self.gridLayout_4.addWidget(self.label_13, 2, 3, 1, 1)
        self.popupDurationBox = QtWidgets.QSpinBox(self.groupBox_8)
        self.popupDurationBox.setMaximum(10)
        self.popupDurationBox.setObjectName("popupDurationBox")
        self.gridLayout_4.addWidget(self.popupDurationBox, 1, 1, 1, 1)
        self.popupOpacityBox = QtWidgets.QDoubleSpinBox(self.groupBox_8)
        self.popupOpacityBox.setDecimals(1)
        self.popupOpacityBox.setMinimum(0.1)
        self.popupOpacityBox.setMaximum(1.0)
        self.popupOpacityBox.setSingleStep(0.1)
        self.popupOpacityBox.setObjectName("popupOpacityBox")
        self.gridLayout_4.addWidget(self.popupOpacityBox, 2, 1, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.groupBox_8)
        self.label_9.setObjectName("label_9")
        self.gridLayout_4.addWidget(self.label_9, 1, 3, 1, 1)
        self.label_23 = QtWidgets.QLabel(self.groupBox_8)
        self.label_23.setObjectName("label_23")
        self.gridLayout_4.addWidget(self.label_23, 1, 0, 1, 1)
        spacerItem14 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem14, 1, 2, 1, 1)
        self.gridLayout_11.addWidget(self.groupBox_8, 0, 0, 1, 2)
        spacerItem15 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_11.addItem(spacerItem15, 3, 0, 1, 2)
        spacerItem16 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_11.addItem(spacerItem16, 5, 0, 2, 2)
        self.popupEnableBox = QtWidgets.QCheckBox(self.page_5)
        self.popupEnableBox.setObjectName("popupEnableBox")
        self.gridLayout_11.addWidget(self.popupEnableBox, 7, 0, 1, 1)
        self.stackedWidget.addWidget(self.page_5)
        self.gridLayout.addWidget(self.stackedWidget, 0, 2, 1, 1)
        self.gridLayout_8.addLayout(self.gridLayout, 0, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.stackedWidget.setCurrentIndex(0)
        self.buttonBox.accepted.connect(Dialog.accept)
        self.buttonBox.rejected.connect(Dialog.reject)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Preferences"))
        __sortingEnabled = self.sideMenuList.isSortingEnabled()
        self.sideMenuList.setSortingEnabled(False)
        item = self.sideMenuList.item(0)
        item.setText(_translate("Dialog", "General"))
        item = self.sideMenuList.item(1)
        item.setText(_translate("Dialog", "Appearance"))
        item = self.sideMenuList.item(2)
        item.setText(_translate("Dialog", "Library viewer"))
        item = self.sideMenuList.item(3)
        item.setText(_translate("Dialog", "Popup"))
        self.sideMenuList.setSortingEnabled(__sortingEnabled)
        self.resetButton.setText(_translate("Dialog", "Reset to default"))
        self.groupBox_4.setTitle(_translate("Dialog", "Music database"))
        self.dbAddButton.setText(_translate("Dialog", "Add"))
        self.dbDeleteButton.setText(_translate("Dialog", "Delete"))
        self.dbResetButton.setToolTip(_translate("Dialog", "Deep database refresh"))
        self.dbResetButton.setText(_translate("Dialog", "..."))
        self.dbTree.headerItem().setText(0, _translate("Dialog", "Library paths"))
        self.dbTree.headerItem().setText(1, _translate("Dialog", "Status"))
        self.groupBox_3.setTitle(_translate("Dialog", "Behavior"))
        self.deleteConfirmBox.setText(_translate("Dialog", "Confirm before deletion"))
        self.resumePlaybackBox.setText(_translate("Dialog", "Resume playback"))
        self.cleanFolderBox.setText(_translate("Dialog", "Remove empty folders"))
        self.label_3.setText(_translate("Dialog", "File manager"))
        self.groupBox_2.setTitle(_translate("Dialog", "Tray icon"))
        self.trayIconBox.setText(_translate("Dialog", "Show tray icon"))
        self.trayMinimizeBox.setText(_translate("Dialog", "Minimize to tray"))
        self.groupBox_10.setTitle(_translate("Dialog", "Icon theme"))
        self.lightThemeRadio.setText(_translate("Dialog", "Light"))
        self.darkThemeRadio.setText(_translate("Dialog", "Dark"))
        self.groupBox_7.setTitle(_translate("Dialog", "Art viewer"))
        self.artTriggerSelectionBox.setText(_translate("Dialog", "Library selection changed"))
        self.label_5.setText(_translate("Dialog", "Viewer size (px)"))
        self.label.setText(_translate("Dialog", "Update triggers"))
        self.artTriggerMediaBox.setText(_translate("Dialog", "Current media changed"))
        self.artShowEmptyBox.setText(_translate("Dialog", "Always show art viewer"))
        self.groupBox_6.setTitle(_translate("Dialog", "Sorting routine"))
        self.label_10.setText(_translate("Dialog", "Available"))
        self.label_4.setText(_translate("Dialog", "Selected"))
        self.sortByDefaultBox.setText(_translate("Dialog", "Enable sorting by default"))
        self.groupBox_5.setTitle(_translate("Dialog", "General"))
        self.stripTitlesBox.setText(_translate("Dialog", "Strip artist / album redundancy from headerless titles"))
        self.label_12.setText(_translate("Dialog", "Window title format"))
        self.label_11.setText(_translate("Dialog", "Notification format"))
        self.expandLibraryBox.setText(_translate("Dialog", "Auto expand library view (filter)"))
        self.label_2.setText(_translate("Dialog", "Tooltip format"))
        self.groupBox.setTitle(_translate("Dialog", "Fonts"))
        self.label_20.setText(_translate("Dialog", "Family"))
        self.label_19.setText(_translate("Dialog", "Size"))
        self.groupBox_9.setTitle(_translate("Dialog", "Geometry"))
        self.label_7.setText(_translate("Dialog", "Vertical offset (px)"))
        self.label_24.setText(_translate("Dialog", "Position"))
        self.label_22.setText(_translate("Dialog", "Width (px)"))
        self.label_25.setText(_translate("Dialog", "Height (px)"))
        self.label_6.setText(_translate("Dialog", "Horizontal offset (px)"))
        self.groupBox_8.setTitle(_translate("Dialog", "Appearance"))
        self.label_21.setText(_translate("Dialog", "Opacity (%)"))
        self.popupBackgroundButton.setToolTip(_translate("Dialog", "Browse background color"))
        self.popupBackgroundButton.setText(_translate("Dialog", "..."))
        self.popupForegroundButton.setToolTip(_translate("Dialog", "Browse foreground color"))
        self.popupForegroundButton.setText(_translate("Dialog", "..."))
        self.label_13.setText(_translate("Dialog", "Foreground"))
        self.label_9.setText(_translate("Dialog", "Background"))
        self.label_23.setText(_translate("Dialog", "Duration (second)"))
        self.popupEnableBox.setText(_translate("Dialog", "Enable popup notifications"))

