# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qoob/ui/player.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(800, 620)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.tabLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.tabLayout.setContentsMargins(10, 10, 10, 10)
        self.tabLayout.setObjectName("tabLayout")
        self.shuffleButton = QtWidgets.QToolButton(self.centralwidget)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("icons/shuffle_off.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.shuffleButton.setIcon(icon)
        self.shuffleButton.setObjectName("shuffleButton")
        self.tabLayout.addWidget(self.shuffleButton, 0, 7, 1, 1)
        self.playButton = QtWidgets.QToolButton(self.centralwidget)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("icons/play.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.playButton.setIcon(icon1)
        self.playButton.setObjectName("playButton")
        self.tabLayout.addWidget(self.playButton, 0, 4, 1, 1)
        self.previousButton = QtWidgets.QToolButton(self.centralwidget)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("icons/previous.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.previousButton.setIcon(icon2)
        self.previousButton.setObjectName("previousButton")
        self.tabLayout.addWidget(self.previousButton, 0, 5, 1, 1)
        self.libraryFrame = QtWidgets.QFrame(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.libraryFrame.sizePolicy().hasHeightForWidth())
        self.libraryFrame.setSizePolicy(sizePolicy)
        self.libraryFrame.setMinimumSize(QtCore.QSize(300, 0))
        self.libraryFrame.setMaximumSize(QtCore.QSize(300, 16777215))
        self.libraryFrame.setLineWidth(0)
        self.libraryFrame.setObjectName("libraryFrame")
        self.libraryLayout = QtWidgets.QVBoxLayout(self.libraryFrame)
        self.libraryLayout.setContentsMargins(-1, 0, -1, 0)
        self.libraryLayout.setObjectName("libraryLayout")
        self.artFrame = QtWidgets.QFrame(self.libraryFrame)
        self.artFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.artFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.artFrame.setObjectName("artFrame")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.artFrame)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.artLabel = QtWidgets.QLabel(self.artFrame)
        self.artLabel.setMaximumSize(QtCore.QSize(280, 280))
        self.artLabel.setText("")
        self.artLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.artLabel.setObjectName("artLabel")
        self.horizontalLayout.addWidget(self.artLabel)
        self.libraryLayout.addWidget(self.artFrame)
        self.frame = QtWidgets.QFrame(self.libraryFrame)
        self.frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame.setObjectName("frame")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label = QtWidgets.QLabel(self.frame)
        self.label.setMaximumSize(QtCore.QSize(70, 16777215))
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 0, 0, 1, 1)
        self.libraryFilterLine = QtWidgets.QLineEdit(self.frame)
        self.libraryFilterLine.setObjectName("libraryFilterLine")
        self.gridLayout_2.addWidget(self.libraryFilterLine, 0, 1, 1, 1)
        self.libraryFilterClearButton = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.libraryFilterClearButton.sizePolicy().hasHeightForWidth())
        self.libraryFilterClearButton.setSizePolicy(sizePolicy)
        self.libraryFilterClearButton.setMaximumSize(QtCore.QSize(16, 16))
        self.libraryFilterClearButton.setStyleSheet("")
        self.libraryFilterClearButton.setText("")
        self.libraryFilterClearButton.setObjectName("libraryFilterClearButton")
        self.gridLayout_2.addWidget(self.libraryFilterClearButton, 0, 2, 1, 1)
        self.libraryLayout.addWidget(self.frame)
        self.frame_2 = QtWidgets.QFrame(self.libraryFrame)
        self.frame_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_2.setLineWidth(0)
        self.frame_2.setObjectName("frame_2")
        self.gridLayout = QtWidgets.QGridLayout(self.frame_2)
        self.gridLayout.setContentsMargins(0, 7, 0, 7)
        self.gridLayout.setObjectName("gridLayout")
        self.preferencesButton = QtWidgets.QToolButton(self.frame_2)
        self.preferencesButton.setObjectName("preferencesButton")
        self.gridLayout.addWidget(self.preferencesButton, 0, 0, 1, 1)
        self.collapseButton = QtWidgets.QToolButton(self.frame_2)
        self.collapseButton.setObjectName("collapseButton")
        self.gridLayout.addWidget(self.collapseButton, 0, 6, 1, 1)
        self.expandButton = QtWidgets.QToolButton(self.frame_2)
        self.expandButton.setObjectName("expandButton")
        self.gridLayout.addWidget(self.expandButton, 0, 7, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 3, 1, 1)
        self.artButton = QtWidgets.QToolButton(self.frame_2)
        self.artButton.setObjectName("artButton")
        self.gridLayout.addWidget(self.artButton, 0, 2, 1, 1)
        self.refreshButton = QtWidgets.QToolButton(self.frame_2)
        self.refreshButton.setObjectName("refreshButton")
        self.gridLayout.addWidget(self.refreshButton, 0, 1, 1, 1)
        self.libraryLayout.addWidget(self.frame_2)
        self.tabLayout.addWidget(self.libraryFrame, 1, 0, 1, 1)
        self.nextButton = QtWidgets.QToolButton(self.centralwidget)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("icons/next.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.nextButton.setIcon(icon3)
        self.nextButton.setObjectName("nextButton")
        self.tabLayout.addWidget(self.nextButton, 0, 6, 1, 1)
        self.stopButton = QtWidgets.QToolButton(self.centralwidget)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap("icons/stop.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.stopButton.setIcon(icon4)
        self.stopButton.setObjectName("stopButton")
        self.tabLayout.addWidget(self.stopButton, 0, 3, 1, 1)
        self.playbackSlider = QtWidgets.QSlider(self.centralwidget)
        self.playbackSlider.setOrientation(QtCore.Qt.Horizontal)
        self.playbackSlider.setObjectName("playbackSlider")
        self.tabLayout.addWidget(self.playbackSlider, 0, 0, 1, 2)
        self.volumeSlider = QtWidgets.QSlider(self.centralwidget)
        self.volumeSlider.setMaximumSize(QtCore.QSize(100, 16777215))
        self.volumeSlider.setMaximum(100)
        self.volumeSlider.setOrientation(QtCore.Qt.Horizontal)
        self.volumeSlider.setTickPosition(QtWidgets.QSlider.TicksBothSides)
        self.volumeSlider.setTickInterval(50)
        self.volumeSlider.setObjectName("volumeSlider")
        self.tabLayout.addWidget(self.volumeSlider, 0, 2, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.menuBar = QtWidgets.QMenuBar(MainWindow)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 800, 20))
        self.menuBar.setObjectName("menuBar")
        MainWindow.setMenuBar(self.menuBar)
        self.actionPreferences = QtWidgets.QAction(MainWindow)
        self.actionPreferences.setObjectName("actionPreferences")

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.shuffleButton.setToolTip(_translate("MainWindow", "Shuffle"))
        self.shuffleButton.setText(_translate("MainWindow", "..."))
        self.playButton.setToolTip(_translate("MainWindow", "Play / Pause"))
        self.playButton.setText(_translate("MainWindow", "..."))
        self.previousButton.setToolTip(_translate("MainWindow", "Previous"))
        self.previousButton.setText(_translate("MainWindow", "..."))
        self.label.setText(_translate("MainWindow", "Filter"))
        self.libraryFilterClearButton.setToolTip(_translate("MainWindow", "Clear filter"))
        self.preferencesButton.setToolTip(_translate("MainWindow", "Preferences"))
        self.preferencesButton.setText(_translate("MainWindow", "..."))
        self.collapseButton.setToolTip(_translate("MainWindow", "Collapse all"))
        self.collapseButton.setText(_translate("MainWindow", "..."))
        self.expandButton.setToolTip(_translate("MainWindow", "Expand all"))
        self.expandButton.setText(_translate("MainWindow", "..."))
        self.artButton.setToolTip(_translate("MainWindow", "Art viewer"))
        self.artButton.setText(_translate("MainWindow", "..."))
        self.refreshButton.setToolTip(_translate("MainWindow", "Quick database refresh"))
        self.refreshButton.setText(_translate("MainWindow", "..."))
        self.nextButton.setToolTip(_translate("MainWindow", "Next"))
        self.nextButton.setText(_translate("MainWindow", "..."))
        self.stopButton.setToolTip(_translate("MainWindow", "Stop"))
        self.stopButton.setText(_translate("MainWindow", "..."))
        self.actionPreferences.setText(_translate("MainWindow", "Preferences"))

